load_allowed_origins

Function load_allowed_origins 

pub fn load_allowed_origins(origins_path: &String) -> Vec<AllowedOrigin>
Load the origin allow-list from a file (--origins). Each line defines one rule: src_addr, protocol[, protocol…]

src_addr is an anycast IP address or unicastv4/unicastv6; the protocol list may be all to allow all protocols.

Arguments

  • origins_path - the path to the origins file

Returns

  • The list of allowed origins

Panics

If the file does not exist, contains malformed entries, or defines no rules.